//+------------------------------------------------------------------+
//|                                              NTC_GetLeverage.mqh |
//|                                              Copyright 2018, NTC |
//|                                                    www.remeco.cz |
//+------------------------------------------------------------------+
#property copyright "Copyright 2018, NTC"
#property link      "www.remeco.cz"
#property strict

#include "NTC_GetExchangeRate.mqh"

int GetSymbolLeverage(const string symbol,const bool tickValueInMarginCurrency=false,const bool verbose=false)
  {
   double
      marginRequired=MarketInfo(symbol,MODE_MARGINREQUIRED),
      leverage;
   if(marginRequired<DBL_EPSILON)
     {
      if(verbose)
         printf("Can't get the margin required value for the symbol: %s",symbol);
      return(0);
     }
   bool
      useExchange;
   int
      marginCalcMode=(int)MarketInfo(symbol,MODE_MARGINCALCMODE);
   if(marginCalcMode==0)
     {
      double
         contractSize=SymbolInfoDouble(symbol,SYMBOL_TRADE_CONTRACT_SIZE);
      if(verbose && contractSize<DBL_EPSILON)
         printf("Can't get the contract size value for the symbol: %s",symbol);
      leverage=contractSize/marginRequired;
      useExchange=true;
     }
   else
     {
      double
         marketPrice=SymbolInfoDouble(symbol,SYMBOL_BID),
         tickValue=SymbolInfoDouble(symbol,SYMBOL_TRADE_TICK_VALUE),
         tickSize=SymbolInfoDouble(symbol,SYMBOL_TRADE_TICK_SIZE);
      if(verbose && marketPrice<DBL_EPSILON)
         printf("Can't get the market price for the symbol: %s",symbol);
      if(verbose && tickValue<DBL_EPSILON)
         printf("Can't get the tick value for the symbol: %s",symbol);
      if(verbose && tickSize<DBL_EPSILON)
         printf("Can't get the tick size for the symbol: %s",symbol);
      leverage=marketPrice*tickValue/(tickSize*marginRequired);
      useExchange=tickValueInMarginCurrency;
     }
   if(useExchange)
     {
      string
         currencyMargin=SymbolInfoString(symbol,SYMBOL_CURRENCY_MARGIN),
         currencyAccount=AccountInfoString(ACCOUNT_CURRENCY);
      double
         exchange=GetExchangeRate(currencyMargin,currencyAccount);
      if(verbose && exchange<DBL_EPSILON)
         printf("Can't get the exchange rate for %s%s",currencyMargin,currencyAccount);
      leverage*=exchange;
     }
   leverage=round(leverage);
   return((int)leverage);
  }

int GetPossibleSymbolLeverage(const string symbol,bool& tickValueInMarginCurrency,const bool verbose=false)
  {
   int
      leverageTickValueInAccountCurrency=GetSymbolLeverage(symbol,false,verbose),
      leverageTickValueInMarginCurrency=GetSymbolLeverage(symbol,true,verbose),
      possibleLeverage[]={2,5,10,20,30},
      countLeverages=ArraySize(possibleLeverage);
   bool
      tickValueInAccountCurrency=false;
   tickValueInMarginCurrency=false;
   for(int i=0;i<countLeverages && !(tickValueInAccountCurrency || tickValueInMarginCurrency);i++)
     {
      tickValueInAccountCurrency=leverageTickValueInAccountCurrency==possibleLeverage[i];
      tickValueInMarginCurrency=leverageTickValueInMarginCurrency==possibleLeverage[i];
     }
   if(tickValueInAccountCurrency)
     {
      tickValueInMarginCurrency=false;
      return(leverageTickValueInAccountCurrency);
     }
   else if(tickValueInMarginCurrency) return(leverageTickValueInMarginCurrency);
   return(0.0);
  }


//+------------------------------------------------------------------+
